import Koa from 'koa';
import Router from 'koa-router';
import koaBody from 'koa-body';
import path from 'path';
import fs from 'fs';
import serve from 'koa-static';
import { File } from 'formidable';
import { render} from "ejs"
import { readdir, readFile } from 'fs/promises';

export const app = new Koa();
const router = new Router();

const uploadDir = '/mnt/d/cloud/'

// 设置上传文件存储目录
// const uploadDir = path.join(__dirname, '../uploads');

// 确保上传目录存在
// if (!fs.existsSync(uploadDir)) {
//   fs.mkdirSync(uploadDir);
// }

// 使用 koa-body 中间件处理文件上传
app.use(
  koaBody({
    multipart: true,
    formidable: {
      uploadDir: uploadDir, // 上传文件存储目录
      keepExtensions: true, // 保留文件扩展名
      maxFileSize: 2048 * 1024 * 1024, // 设置最大文件大小为600MB
      filename(name, ext, part, form) {
        return part.originalFilename || `${name}${ext}`
      }
    },
  })
)

// 静态文件服务，用于访问上传的文件
app.use(serve(uploadDir));

// 首页路由，显示文件列表和上传按钮
router.get('/', async (ctx) => {
  const files = await readdir(uploadDir);
  let file = await readFile(path.join(__dirname, 'template/index.ejs'));
  ctx.body = render(file.toString(), {files})
});

// 文件上传路由
router.post('/upload', async (ctx) => {
  // 检查是否有文件上传
  if (!ctx.request.files || !ctx.request.files.file) {
    ctx.status = 400;
    ctx.body = '未上传文件';
    return;
  }

  // 获取上传的文件对象
  const file = ctx.request.files.file;

  // 处理单个文件或多个文件
  let fileName: string;
  if (Array.isArray(file)) {
    // 多个文件
    fileName = file.map((f: File) => f.originalFilename || f.newFilename).join(', ');
  } else {
    // 单个文件
    fileName = file.originalFilename || file.newFilename;
  }

  // 返回文件名
  ctx.body = `文件上传成功，文件名：${fileName}`;
  ctx.redirect('/');
});

// 使用路由中间件
app.use(router.routes()).use(router.allowedMethods());
